==> landscapeR_1.1.3.tar.gz: landscapeR/NEWS.md <==
landscapeR v1.1.3 (Patch release date: 2016-12-13)
-----------------------------------------------
CHANGES:

* New mantainer's email address in the DESCRIPTION file
* Minor documentation edits in all functions
* Slight speed improvements with performant native R functions


landscapeR v1.1.2 (Patch release date: 2016-09-07)
-----------------------------------------------
CHANGES:

* Bug fix in 'makeClass'
* Clarified error messages


landscapeR v1.1.1 (Patch release date: 2016-08-31)
-----------------------------------------------
CHANGES:

* Fixed bug in 'rmSingle'
* Replaced outdated version of documentation 


landscapeR v1.1 (Release date: 2016-08-30)
-----------------------------------------------
CHANGES:

* Removed dependency from package 'fastmatch'
* Changed 'makePatch' and 'expandClass' function internals to gain significant speed improvements
* Updated and improved error/warning messages and exception handling
* Functions 'makeClass' and 'expandClass' now accept vectors for argument "bgr"
* Updated DESCRIPTION file
* Updated and expanded vignette 
* Added copyright notes in COPYRIGHT file
* Fixed author list to CRAN standards

NEW:

* Added vignette
* Added function 'rmSingle' to remove single tones and reduce salt-pepper effect
* Added function  'makeLine' to create linear features (directional and convoluted). Beta version.
* Added NEWS.md file
* Added start up messages with copyright notice


landscapeR v1.0.0 (Release date: 2016-05-22)
-----------------------------------------------
NEW FEATURES:

* First release on CRAN

==> landscapeR_1.2.tar.gz: landscapeR/NEWS.md <==
landscapeR v1.2 (Release date: 2017-07-05)
-----------------------------------------------
CHANGES:

* Hidden internal functions translated to C++ for significant speed inprovements


landscapeR v1.1.3 (Patch release date: 2016-12-13)
-----------------------------------------------
CHANGES:

* New mantainers's email address in the DESCRIPTION file
* Minor documentation edits in all functions
* Slight speed improvements with performant native R functions


landscapeR v1.1.2 (Patch release date: 2016-09-07)
-----------------------------------------------
CHANGES:

* Bug fix in 'makeClass'
* Clarified error messages


landscapeR v1.1.1 (Patch release date: 2016-08-31)
-----------------------------------------------
CHANGES:

* Fixed bug in 'rmSingle'
* Replaced outdated version of documentation 


landscapeR v1.1 (Release date: 2016-08-30)
-----------------------------------------------
CHANGES:

* Removed dependency from package 'fastmatch'
* Changed 'makePatch' and 'expandClass' function internals to gain significant speed improvements
* Updated and improved error/warning messages and exception handling
* Functions 'makeClass' and 'expandClass' now accept vectors for argument "bgr"
* Updated DESCRIPTION file
* Updated and expanded vignette 
* Added copyright notes in COPYRIGHT file
* Fixed author list to CRAN standards

NEW:

* Added vignette
* Added function 'rmSingle' to remove single tones and reduce salt-pepper effect
* Added function  'makeLine' to create linear features (directional and convoluted). Beta version.
* Added NEWS.md file
* Added start up messages with copyright notice


landscapeR v1.0.0 (Release date: 2016-05-22)
-----------------------------------------------
NEW FEATURES:

* First release on CRAN
